@@ -44,15 +44,15 @@ namespace KWin
 
 static void readDisplay(int pipe);
 
-WaylandTestApplication::WaylandTestApplication(int &argc, char **argv)
-    : Application(OperationModeXwayland, argc, argv)
+WaylandTestApplication::WaylandTestApplication(OperationMode mode, int &argc, char **argv)
+    : Application(mode, argc, argv)
 {
     QStandardPaths::setTestModeEnabled(true);
 #ifdef KWIN_BUILD_ACTIVITIES
     setUseKActivities(false);
 #endif
     qputenv("KWIN_COMPOSE", QByteArrayLiteral("Q"));
-    initPlatform(KPluginMetaData(QStringLiteral(KWINBACKENDPATH)));
+    initPlatform(KPluginMetaData(QStringLiteral("KWinWaylandVirtualBackend.so")));
     WaylandServer::create(this);
 }
 
@@ -117,10 +117,21 @@ void WaylandTestApplication::continueStartupWithScreens()
     disconnect(kwinApp()->platform(), &Platform::screensQueried, this, &WaylandTestApplication::continueStartupWithScreens);
     createScreens();
 
+    if (operationMode() == OperationModeWaylandOnly) {
+        createCompositor();
+        connect(Compositor::self(), &Compositor::sceneCreated, this, &WaylandTestApplication::continueStartupWithSceen);
+        return;
+    }
     createCompositor();
     connect(Compositor::self(), &Compositor::sceneCreated, this, &WaylandTestApplication::startXwaylandServer);
 }
 
+void WaylandTestApplication::continueStartupWithSceen()
+{
+    disconnect(Compositor::self(), &Compositor::sceneCreated, this, &WaylandTestApplication::continueStartupWithSceen);
+    createWorkspace();
+}
+
 void WaylandTestApplication::continueStartupWithX()
 {
     createX11Connection();
