@@ -29,8 +29,10 @@ namespace KWayland
 {
 namespace Client
 {
+class AppMenuManager;
 class ConnectionThread;
 class Compositor;
+class IdleInhibitManager;
 class PlasmaShell;
 class PlasmaWindowManagement;
 class PointerConstraints;
@@ -54,7 +56,7 @@ class WaylandTestApplication : public Application
 {
     Q_OBJECT
 public:
-    WaylandTestApplication(int &argc, char **argv);
+    WaylandTestApplication(OperationMode mode, int &argc, char **argv);
     virtual ~WaylandTestApplication();
 
 protected:
@@ -64,6 +66,7 @@ private:
     void createBackend();
     void createX11Connection();
     void continueStartupWithScreens();
+    void continueStartupWithSceen();
     void continueStartupWithX();
     void startXwaylandServer();
 
@@ -80,7 +83,9 @@ enum class AdditionalWaylandInterface {
     Decoration = 1 << 1,
     PlasmaShell = 1 << 2,
     WindowManagement = 1 << 3,
-    PointerConstraints = 1 << 4
+    PointerConstraints = 1 << 4,
+    IdleInhibition = 1 << 5,
+    AppMenu = 1 << 6
 };
 Q_DECLARE_FLAGS(AdditionalWaylandInterfaces, AdditionalWaylandInterface)
 /**
@@ -108,6 +113,9 @@ KWayland::Client::ServerSideDecorationManager *waylandServerSideDecoration();
 KWayland::Client::PlasmaShell *waylandPlasmaShell();
 KWayland::Client::PlasmaWindowManagement *waylandWindowManagement();
 KWayland::Client::PointerConstraints *waylandPointerConstraints();
+KWayland::Client::IdleInhibitManager *waylandIdleInhibitManager();
+KWayland::Client::AppMenuManager *waylandAppMenuManager();
+
 
 bool waitForWaylandPointer();
 bool waitForWaylandTouch();
@@ -118,7 +126,8 @@ void flushWaylandConnection();
 KWayland::Client::Surface *createSurface(QObject *parent = nullptr);
 enum class ShellSurfaceType {
     WlShell,
-    XdgShellV5
+    XdgShellV5,
+    XdgShellV6
 };
 QObject *createShellSurface(ShellSurfaceType type, KWayland::Client::Surface *surface, QObject *parent = nullptr);
 KWayland::Client::ShellSurface *createShellSurface(KWayland::Client::Surface *surface, QObject *parent = nullptr);
@@ -170,19 +179,26 @@ bool unlockScreen();
 Q_DECLARE_OPERATORS_FOR_FLAGS(KWin::Test::AdditionalWaylandInterfaces)
 Q_DECLARE_METATYPE(KWin::Test::ShellSurfaceType)
 
-#define WAYLANDTEST_MAIN_HELPER(TestObject, DPI) \
+#define WAYLANDTEST_MAIN_HELPER(TestObject, DPI, OperationMode) \
 int main(int argc, char *argv[]) \
 { \
     setenv("QT_QPA_PLATFORM", "wayland-org.kde.kwin.qpa", true); \
-    setenv("QT_QPA_PLATFORM_PLUGIN_PATH", KWINQPAPATH, true); \
+    setenv("QT_QPA_PLATFORM_PLUGIN_PATH", QFileInfo(QString::fromLocal8Bit(argv[0])).absolutePath().toLocal8Bit().constData(), true); \
     setenv("KWIN_FORCE_OWN_QPA", "1", true); \
     DPI; \
-    KWin::WaylandTestApplication app(argc, argv); \
+    KWin::WaylandTestApplication app(OperationMode, argc, argv); \
     app.setAttribute(Qt::AA_Use96Dpi, true); \
+    const auto ownPath = app.libraryPaths().last(); \
+    app.removeLibraryPath(ownPath); \
+    app.addLibraryPath(ownPath); \
     TestObject tc; \
     return QTest::qExec(&tc, argc, argv); \
 }
 
-#define WAYLANDTEST_MAIN(TestObject) WAYLANDTEST_MAIN_HELPER(TestObject, QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling) )
+#ifdef NO_XWAYLAND
+#define WAYLANDTEST_MAIN(TestObject) WAYLANDTEST_MAIN_HELPER(TestObject, QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling), KWin::Application::OperationModeWaylandOnly)
+#else
+#define WAYLANDTEST_MAIN(TestObject) WAYLANDTEST_MAIN_HELPER(TestObject, QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling), KWin::Application::OperationModeXwayland)
+#endif
 
 #endif
