@@ -101,6 +101,8 @@ void QuickTilingTest::initTestCase()
 
     kwinApp()->setConfig(config);
 
+    qputenv("XKB_DEFAULT_RULES", "evdev");
+
     kwinApp()->start();
     QVERIFY(workspaceCreatedSpy.wait());
     QCOMPARE(screens()->count(), 2);
@@ -582,23 +584,7 @@ void QuickTilingTest::testX11QuickTilingAfterVertMaximize()
     QVERIFY(quickTileChangedSpy.isValid());
     QFETCH(QuickTileMode, mode);
     client->setQuickTileMode(mode, true);
-    QEXPECT_FAIL("left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("right", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top right", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom right", "Quick tiling not working", Continue);
     QCOMPARE(client->quickTileMode(), mode);
-    QEXPECT_FAIL("left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("right", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("top right", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom left", "Quick tiling not working", Continue);
-    QEXPECT_FAIL("bottom right", "Quick tiling not working", Continue);
     QTEST(client->geometry(), "expectedGeometry");
     QEXPECT_FAIL("", "We get two changed events", Continue);
     QCOMPARE(quickTileChangedSpy.count(), 1);
