@@ -25,8 +25,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QObject>
 
+#include <memory>
+
 namespace KWin
 {
+class SyncFilter;
 class XInputIntegration;
 class WindowSelector;
 class X11EventFilter;
@@ -64,6 +67,9 @@ public:
 
     void invertScreen() override;
 
+    void createEffectsHandler(Compositor *compositor, Scene *scene) override;
+    QVector<CompositingType> supportedCompositors() const override;
+
 protected:
     void doHideCursor() override;
     void doShowCursor() override;
@@ -86,6 +92,7 @@ private:
     Display *m_x11Display;
     QScopedPointer<WindowSelector> m_windowSelector;
     QScopedPointer<X11EventFilter> m_screenEdgesFilter;
+    std::unique_ptr<SyncFilter> m_syncFilter;
 
 };
 
